
def help_mi():
    print("эта библиотека состоит из двух модулей, 1-все вычисления с факториалами(дискретная математика), 2 модуль считает значение строки")
    print('у нас есть функции(модуль math): ')
    print('factorial(n)-Вычисляет факториал числа `n`')
    print('permutation(n)-Возвращает количество перестановок для `n` объектов')
    print('compination(n, k)- Вычисляет количество комбинаций (выборов) из `n` объектов по `k` без учета порядка')
    print('binkof(n, k)- Вычисляет биномиальный коэффициент')
    print('gamma(n)- Возвращает значение функции гамма для `n`')
    print('summaf(n)- Вычисляет сумму факториалов всех целых чисел от 1 до `n`')
    print(' ')
    print(' ')
    print('у нас есть функции(модуль str_op): ')
    print('Task.evaluate("n-u*p/n")-любая формула')
    



if __name__ == '__main__':
    from strop import *

else:
    from mynewlib1.str_op.strop import *


def test_single_number(comments=True):
    if comments:
        print('test_single_number ...')
    assert Task.evaluate('8')==8
    print('.')
    print('.')
    print('.')
    if comments:
        print('test_single_number completed')

def test_addition(comments=True):
    if comments:
        print('test_addition ...')
    assert Task.evaluate('8 + 8')==16
    print('.')
    print('.')
    print('.')
    if comments:
        print('test_addition completed')

def test_multiplication(comments=True):
    if comments:
        print('test_multiplication ...')
    assert Task.evaluate('3*4')==12
    print('.')
    print('.')
    print('.')
    if comments:
        print('test_multiplication completed')

def test_division(comments=True):
    if comments:
        print('test_division ...')
    assert Task.evaluate('10/2') == 5
    print('.')
    print('.')
    print('.')
    if comments:
        print('test_division completed')
test_single_number()
test_addition()
test_multiplication()
test_division()